@@ -10,6 +10,11 @@ try:
     from functools import lru_cache
 except ImportError:
     from backports.functools_lru_cache import lru_cache
+try:
+    FileNotFoundError
+except NameError:
+    FileNotFoundError = OSError
+
 
 from ..fdio import tmpdir
 
